@@ -182,7 +182,7 @@ public class FacebookConnectionTest  extends TestCase {
                 
     }
 
-    public void testUsageOfExistingAccount() throws Exception{
+    public void testUsageOfExistingAccount(){
         final List<Contact> contacts = facebook.getContacts(null,1,1,1);
         for (final Contact contact : contacts){
             System.out.println(contact.getGivenName() + " " + contact.getSurName());
